@@ -23,15 +23,16 @@ Log::ProgramInfo - log global info from a perl programs.
 #                                                        Make output more easily parsable
 # 0.1.7                 2015-05-20      John Macdonald   Add user-pluggable log routines
 #                                                        Move log parser from test to module.
+# 0.1.8                 2015-06-12      John Macdonald   Catch most signals (not just HUP)
 #
 
 =head1 VERSION
 
-Version 0.1.7
+Version 0.1.8
 
 =cut
 
-our $VERSION = '0.1.7';
+our $VERSION = '0.1.8';
 
 use feature qw(say);
 use Data::Dumper;
@@ -322,6 +323,12 @@ BEGIN {
     while( my($k,$v) = each %_omap ) {
         $env_options{$v} = $ENV{$k} if exists $ENV{$k};
     }
+    $SIG{HUP}  = \&catch_sig;
+    $SIG{INT}  = \&catch_sig;
+    $SIG{PIPE} = \&catch_sig;
+    $SIG{TERM} = \&catch_sig;
+    $SIG{USR1} = \&catch_sig;
+    $SIG{USR2} = \&catch_sig;
 }
 
 sub import {
@@ -350,7 +357,6 @@ sub import {
     croak "Unknown logdate option: $option{logdate}"
         unless exists $valid_dates{ $option{logdate} };
 
-    $SIG{HUP} = \&catch_sig;
     say STDERR "resolved option hash: ", Dumper(\%option) if $ENV{DUMP_LOG_IMPORTS};
 }
 
